import 'package:equatable/equatable.dart';

abstract class RestorePasswordPhoneVerificationState extends Equatable {
  const RestorePasswordPhoneVerificationState();

  @override
  List<Object> get props => [];
}

class RestorePasswordPhoneVerificationInitial
    extends RestorePasswordPhoneVerificationState {}

class RestorePasswordPhoneVerificationLoading
    extends RestorePasswordPhoneVerificationState {}

class RestorePasswordPhoneVerificationSuccess
    extends RestorePasswordPhoneVerificationState {}

class RestorePasswordPhoneVerificationFailure
    extends RestorePasswordPhoneVerificationState {
  final String error;

  const RestorePasswordPhoneVerificationFailure(this.error);

  @override
  List<Object> get props => [error];
}

class RestorePasswordPhoneVerificationFieldsState
    extends RestorePasswordPhoneVerificationState {
  final bool areFieldsFilled;

  const RestorePasswordPhoneVerificationFieldsState(this.areFieldsFilled);

  @override
  List<Object> get props => [areFieldsFilled];
}
